@@ -24,10 +24,11 @@
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <glom/bakery/app_withdoc_gtk.h>
-
 #include <glom/frame_glom.h>
-
-
+#include <glom/show_progress_message.h>
+#include <glom/infobar_progress_creating.h>
+#include <gtkmm/aboutdialog.h>
+#include <gtkmm/messagedialog.h>
 
 //Avoid including the header here:
 extern "C"
@@ -41,7 +42,6 @@ namespace Glom
 {
 
 class Window_Translations;
-class Dialog_ProgressCreating; //TODO: Rename this because it's not just about creating databases.
 
 class Application : public GlomBakery::App_WithDoc_Gtk
 {
@@ -124,6 +124,10 @@ public:
    */
   void start_new_record();
 
+  void set_progress_message(const Glib::ustring& message);
+  void pulse_progress_message();
+  void clear_progress_message();
+
   static Application* get_application();
 
 protected:
@@ -162,7 +166,7 @@ private:
   void on_menu_developer_active_platform_maemo();
   void on_menu_developer_export_backup();
   void on_menu_developer_restore_backup();
-  void on_menu_developer_show_layout_toolbar();
+  void on_menu_developer_enable_layout_drag_and_drop ();
 
   void on_window_translations_hide();
 
@@ -205,8 +209,6 @@ private:
   void open_browsed_document(const EpcServiceInfo* server, const Glib::ustring& service_name);
 #endif // !G_OS_WIN32
 
-  static Glib::ustring get_file_uri_without_extension(const Glib::ustring& uri);
-
   typedef GlomBakery::App_WithDoc_Gtk type_base;
 
   //Widgets:
@@ -220,7 +222,7 @@ private:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Glib::RefPtr<Gtk::Action> m_action_developer_users;
   Glib::RefPtr<Gtk::RadioAction> m_action_menu_developer_developer, m_action_menu_developer_operator;
-  Glib::RefPtr<Gtk::ToggleAction> m_action_show_layout_toolbar;
+  Glib::RefPtr<Gtk::ToggleAction> m_action_enable_layout_drag_and_drop ;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Glib::RefPtr<Gtk::ToggleAction> m_toggleaction_network_shared;
@@ -232,6 +234,9 @@ private:
   bool m_bAboutShown;
   Gtk::AboutDialog* m_pAbout; //About box.
 
+  Infobar_ProgressCreating* m_infobar_progress;
+  std::string m_progress_collate_key;
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Window_Translations* m_window_translations;
 
@@ -254,9 +259,6 @@ private:
 
   Gtk::MessageDialog* m_avahi_progress_dialog;
 
-  Dialog_ProgressCreating* m_dialog_progress_creating;
-  Dialog_ProgressCreating* m_dialog_progess_save_backup;
-  Dialog_ProgressCreating* m_dialog_progess_convert_backup;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   // This is set to the URI of an example file that is loaded to be able to
