@@ -54,7 +54,7 @@ public:
    */
   virtual Glib::ustring get_report_part_id() const;
 
-  bool get_display_width(guint& width) const;
+  guint get_display_width() const;
   void set_display_width(guint value);
 
   /// This is used only for the print layouts.
@@ -62,7 +62,11 @@ public:
 
   /// This is used only for the print layouts.
   void set_print_layout_position(double x, double y, double width, double height);
+  
+  /// This is used only for the print layouts.
+  void set_print_layout_position_y(double y);
 
+  //TODO: Do we use this? Do we want to?
   /// This is used only for the print layouts.
   void set_print_layout_split_across_pages(bool split = true);
 
