@@ -21,12 +21,12 @@
 #include "box_data_list.h"
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/glade_utils.h>
-#include <glom/report_builder.h>
 #include <glom/mode_design/layout/dialog_layout_list.h>
 #include <libglom/privs.h>
 #include <libglom/db_utils.h>
 #include <libglom/utils.h> //For bold_message()).
 #include <sstream> //For stringstream
+#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -419,7 +419,7 @@ void Box_Data_List::create_layout()
   sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
   if(!field_primary_key)
   {
-    std::cerr << G_STRFUNC << ": primary key not found." << std::endl;
+    std::cerr << G_STRFUNC << ": primary key not found for table: " << m_table_name << std::endl;
     return;
   }
 
