@@ -28,6 +28,7 @@
 #include <libglom/db_utils.h>
 #include <glom/application.h>
 #include <glom/utils_ui.h>
+#include <gtkmm/cellareabox.h>
 #include <glibmm/i18n.h>
 //#include <sstream> //For stringstream
 
@@ -296,7 +297,7 @@ g_warning("ComboGlom::on_button_press_event()");
     if(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_pointer( gtk_widget_get_window (Gtk::Widget::gobj()), 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
