@@ -32,6 +32,9 @@
 #include <gtkmm/label.h>
 #include <gtkmm/uimanager.h>
 #include <glom/utility_widgets/gimpruler/gimpruler.h>
+#include <gtkmm/scrolledwindow.h>
+#include <gtkmm/spinbutton.h>
+#include <gtkmm/button.h>
 #include <gtkmm/builder.h>
 
 namespace Glom
@@ -194,7 +197,7 @@ private:
     m_action_align_left, m_action_align_right;
 
   //Toolbar:
-  Gtk::HandleBox* m_palette_handle_box; //TODO: The toolbar is already a HandleBox.
+  Gtk::Box* m_palette_box;
   std::vector<Gtk::TargetEntry> m_drag_targets_all;
   PrintLayoutToolbar m_toolbar;
   
