@@ -21,7 +21,8 @@
 #ifndef GLOM_MODE_DESIGN_DIALOG_USERS_LIST_H
 #define GLOM_MODE_DESIGN_DIALOG_USERS_LIST_H
 
-#include <gtkmm.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/treeview.h>
 #include <gtkmm/builder.h>
 #include <glom/base_db.h>
 #include "../../utility_widgets/combo_textglade.h"
