@@ -22,6 +22,7 @@
 #define GLOM_UTILITY_WIDGETS_ADDDEL_WITHBUTTONS_H
 
 #include "adddel.h"
+#include <gtkmm/buttonbox.h>
 
 namespace Glom
 {
@@ -46,7 +47,7 @@ private:
   void on_button_edit();
 
   //member widgets:
-  Gtk::HButtonBox m_ButtonBox;
+  Gtk::ButtonBox m_ButtonBox;
   Gtk::Button m_Button_Add;
   Gtk::Button m_Button_Del;
   Gtk::Button m_Button_Edit;
