@@ -28,6 +28,9 @@ namespace Glom
 
 
 CanvasTableMovable::CanvasTableMovable()
+: m_row_line_width(0),
+  m_column_line_width(0)
+  
 {
   signal_motion_notify_event().connect(sigc::mem_fun(*this, &CanvasItemMovable::on_motion_notify_event));
   signal_button_press_event().connect(sigc::mem_fun(*this, &CanvasItemMovable::on_button_press_event));
@@ -76,6 +79,7 @@ void CanvasTableMovable::set_width_height(double width, double height)
   {
     std::cout << "debug: " << G_STRFUNC << ": width is -1" << std::endl;
   }
+
   property_width() = width;
   property_height() = height;
 }
@@ -100,7 +104,7 @@ void CanvasTableMovable::set_grid(const Glib::RefPtr<const CanvasGroupGrid>& gri
 
 void CanvasTableMovable::snap_position_one_corner(Corners corner, double& x, double& y) const
 {
-  Goocanvas::Bounds bounds = get_bounds();
+  const Goocanvas::Bounds bounds = get_bounds();
   const double width = std::abs(bounds.get_x2() - bounds.get_x1());
   const double height = std::abs(bounds.get_y2() - bounds.get_y1());
 
@@ -180,6 +184,32 @@ Goocanvas::Canvas* CanvasTableMovable::get_parent_canvas_widget()
   return get_canvas();
 }
 
+void CanvasTableMovable::set_lines_details(double row_line_width, double column_line_width, const Glib::ustring& color)
+{
+  m_column_line_width = row_line_width;
+  m_row_line_width = column_line_width;
+  m_line_color = color;
+  
+  set_lines_visibility(false);
+}
+
+void CanvasTableMovable::set_lines_visibility(bool show)
+{
+  if(show && 
+    (m_line_color.empty() || ((m_row_line_width == 0) && (m_column_line_width == 0))))
+  {
+    //TODO: Use constants or function calls from somewhere else:
+    property_vert_grid_line_width() = 0.5f;
+    property_horz_grid_line_width() = 0.5f;
+    property_stroke_color() = "black";
+  }
+  else
+  {
+    property_vert_grid_line_width() = m_column_line_width;
+    property_horz_grid_line_width() = m_row_line_width;
+    property_stroke_color() = m_line_color;
+  }
+}
 
 } //namespace Glom
 
