@@ -31,6 +31,7 @@
 #include <gtkmm/stock.h>
 #include <giomm/file.h>
 #include <giomm/contenttype.h>
+#include <libgda/gda-blob-op.h>
 #include <glibmm/convert.h>
 
 #include <iostream>   // for cout, endl
@@ -233,6 +234,12 @@ const GdaBinary* ImageGlom::get_binary() const
   const GdaBinary* gda_binary = 0;
   if(m_original_data.get_value_type() == GDA_TYPE_BINARY)
     gda_binary = gda_value_get_binary(m_original_data.gobj());
+  else if(m_original_data.get_value_type() == GDA_TYPE_BLOB)
+  {
+    const GdaBlob* gda_blob = gda_value_get_blob(m_original_data.gobj());
+    if(gda_blob && gda_blob_op_read_all(const_cast<GdaBlobOp*>(gda_blob->op), const_cast<GdaBlob*>(gda_blob)))
+      gda_binary = &(gda_blob->data);
+  }
   
   return gda_binary;
 }
@@ -581,27 +588,11 @@ static void make_file_read_only(const Glib::ustring& uri)
 
 Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
 {
-  Glib::ustring uri;
-  
-  //Get a temporary file path:
-  std::string filepath;
-  try
+  Glib::ustring uri = Utils::get_temp_file_uri("glom_image");
+  if(uri.empty())
   {
-    const int filehandle = Glib::file_open_tmp(filepath);
-    ::close(filehandle);
+    std::cerr << ": uri is empty." << std::endl;
   }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() failed" << std::endl;
-  }
-  
-  if(filepath.empty())
-  {
-    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath" << std::endl;
-    return uri;
-  }
-  
-  uri = Glib::filename_to_uri(filepath);
   
   bool saved = false;
   if(show_progress)
