@@ -31,9 +31,12 @@
 
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/stock.h>
+#include <glibmm/convert.h>
+#include <glibmm/miscutils.h>
+#include <glibmm/fileutils.h>
 
-#include <giomm.h>
-
+#include <giomm/file.h>
+#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
 #include <string.h> // for strchr
