@@ -30,7 +30,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 {
   Glom::Document document;
   const bool recreated = 
-    test_create_and_selfhost("example_music_collection.glom", document, hosting_mode);
+    test_create_and_selfhost_from_example("example_music_collection.glom", document, hosting_mode);
   if(!recreated)
   {
     std::cerr << "Recreation failed." << std::endl;
